@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015 - 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2015 - 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -20,6 +20,7 @@ public:
     ~LogoWidget() override;
 
     void updateLocale(const QString &locale);
+    static void onDConfigPropertyChanged(const QString &key, const QVariant &value, QObject* objPtr);
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -27,11 +28,16 @@ protected:
 private:
     void initUI();
     QPixmap loadSystemLogo();
+    void loadCustomLogo();
     QString getVersion();
+    void updateCustomLogoPos();
 
 private:
     QLabel *m_logoLabel;
     DLabel *m_logoVersionLabel;
     QString m_locale;
+
+    // 第三方logo配置控制显示
+    QLabel *m_customLogoLabel;
 };
 #endif // LOGOFRAME
