@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -40,10 +40,7 @@ TEST_F(UT_MultiUsersWarningView, BasicTest)
 {
     std::shared_ptr<User> user_ptr(new User());
     m_multiUsersWarningView->action();
-    m_multiUsersWarningView->toggleButtonState();
-    m_multiUsersWarningView->buttonClickHandle();
     m_multiUsersWarningView->setAcceptReason("test");
-    m_multiUsersWarningView->getUserIcon(user_ptr->avatar());
     QTest::keyPress(m_multiUsersWarningView, Qt::Key_Up, Qt::KeyboardModifier::NoModifier);
 
 }
