@@ -80,6 +80,25 @@
         <translation>Iris ID locked, use password please</translation>
     </message>
 </context>
+<context>
+    <name>AuthPasskey</name>
+    <message>
+        <source>Please plug in the security key</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Verification failed</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Identifying the security key</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>AuthPassword</name>
     <message>
@@ -188,78 +207,23 @@
         <translation><numerusform>Your password will expire in %n days, please change it timely</numerusform><numerusform>Your password will expire in %n days, please change it timely</numerusform></translation>
     </message>
     <message>
-        <source>Your password has expired. Please contact the administrator to change it.</source>
-        <translation>Your password has expired. Please contact the administrator to change it.</translation>
+        <source>Password expired, please change</source>
+        <translation>Password expired, please change</translation>
     </message>
     <message>
-        <source>Your password has expired. Please change it.</source>
-        <translation>Your password has expired. Please change it.</translation>
+        <source>Your password has expired. Please contact the administrator to change it</source>
+        <translation>Your password has expired. Please contact the administrator to change it</translation>
+    </message>
+    <message>
+        <source>Terminal locked, please contact administrator</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>ChangePasswordWidget</name>
+    <name>DeepinAuthFramework</name>
     <message>
-        <source>Your password has expired. Please change it and log in again.</source>
-        <translation>Your password has expired. Please change it and log in again.</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation>Save</translation>
-    </message>
-    <message>
-        <source>Old password</source>
-        <translation>Old password</translation>
-    </message>
-    <message>
-        <source>New password</source>
-        <translation>New password</translation>
-    </message>
-    <message>
-        <source>Repeat new password</source>
-        <translation>Repeat new password</translation>
-    </message>
-    <message>
-        <source>Password hint (Optional)</source>
-        <translation>Password hint (Optional)</translation>
-    </message>
-    <message>
-        <source>Passwords do not match</source>
-        <translation>Passwords do not match</translation>
-    </message>
-    <message>
-        <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation>The hint is visible to all users. Do not include the password here.</translation>
-    </message>
-    <message>
-        <source>New password should differ from the current one</source>
-        <translation>New password should differ from the current one</translation>
-    </message>
-    <message>
-        <source>Password changed</source>
-        <translation>Password changed</translation>
-    </message>
-    <message>
-        <source>Wrong password</source>
-        <translation>Wrong password</translation>
-    </message>
-</context>
-<context>
-    <name>ControlWidget</name>
-    <message>
-        <source>Desktop Environment and Display Protocol</source>
-        <translation>Desktop Environment and Display Protocol</translation>
-    </message>
-    <message>
-        <source>Keyboard Layout</source>
-        <translation>Keyboard Layout</translation>
-    </message>
-    <message>
-        <source>Switch User</source>
-        <translation>Switch User</translation>
-    </message>
-    <message>
-        <source>Power</source>
-        <translation>Power</translation>
+        <source>Wrong Password</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -279,6 +243,17 @@
         <source>Cancel</source>
         <translation>Cancel</translation>
     </message>
+    <message>
+        <source>The reason of inhibit.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>LighterGreeter</name>
+    <message>
+        <source>Standard Mode</source>
+        <translation>Standard Mode</translation>
+    </message>
 </context>
 <context>
     <name>LockContent</name>
@@ -318,69 +293,10 @@
     </message>
 </context>
 <context>
-    <name>PasswordLevelWidget</name>
+    <name>SessionWidget</name>
     <message>
-        <source>Weak</source>
-        <translation>Weak</translation>
-    </message>
-    <message>
-        <source>Medium</source>
-        <translation>Medium</translation>
-    </message>
-    <message>
-        <source>Strong</source>
-        <translation>Strong</translation>
-    </message>
-</context>
-<context>
-    <name>PwqualityManager</name>
-    <message>
-        <source>Password cannot be empty</source>
-        <translation>Password cannot be empty</translation>
-    </message>
-    <message>
-        <source>Password must have at least %1 characters</source>
-        <translation>Password must have at least %1 characters</translation>
-    </message>
-    <message>
-        <source>Password must be no more than %1 characters</source>
-        <translation>Password must be no more than %1 characters</translation>
-    </message>
-    <message>
-        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
-    </message>
-    <message>
-        <source>No more than %1 palindrome characters please</source>
-        <translation>No more than %1 palindrome characters please</translation>
-    </message>
-    <message>
-        <source>No more than %1 monotonic characters please</source>
-        <translation>No more than %1 monotonic characters please</translation>
-    </message>
-    <message>
-        <source>No more than %1 repeating characters please</source>
-        <translation>No more than %1 repeating characters please</translation>
-    </message>
-    <message>
-        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
-    </message>
-    <message>
-        <source>Password must not contain more than 4 palindrome characters</source>
-        <translation>Password must not contain more than 4 palindrome characters</translation>
-    </message>
-    <message>
-        <source>Do not use common words and combinations as password</source>
-        <translation>Do not use common words and combinations as password</translation>
-    </message>
-    <message>
-        <source>Create a strong password please</source>
-        <translation>Create a strong password please</translation>
-    </message>
-    <message>
-        <source>It does not meet password rules</source>
-        <translation>It does not meet password rules</translation>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
+        <translation>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</translation>
     </message>
 </context>
 <context>
@@ -409,13 +325,21 @@
         <source>Log out</source>
         <translation>Log out</translation>
     </message>
+    <message>
+        <source>Switch user</source>
+        <translation>Switch user</translation>
+    </message>
     <message>
         <source>Switch system</source>
         <translation>Switch system</translation>
     </message>
     <message>
-        <source>Switch user</source>
-        <translation>Switch user</translation>
+        <source>Update and Shut Down</source>
+        <translation>Update and Shut Down</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Update and Reboot</translation>
     </message>
 </context>
 <context>
@@ -426,25 +350,52 @@
     </message>
 </context>
 <context>
-    <name>UserListPopupWidget</name>
+    <name>UdcpMFALoginWidget</name>
     <message>
-        <source>Standard User</source>
-        <translation>Standard User</translation>
+        <source>发送验证码</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Administrator</source>
-        <translation>Administrator</translation>
+        <source>请输入手机号</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Other Users</source>
-        <translation>Other Users</translation>
+        <source>请输入验证码</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>获取验证码</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>VirtualKeyboardModule</name>
+    <name>UpdateWorker</name>
     <message>
-        <source>Onboard</source>
-        <translation>Onboard</translation>
+        <source>Update</source>
+        <translation>Update</translation>
+    </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation>Please plug in and then install updates.</translation>
+    </message>
+</context>
+<context>
+    <name>UsersWithTheSameName</name>
+    <message>
+        <source>Return</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please select the account for login</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Domain Account</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -505,6 +456,33 @@
         <source>Are you sure you want to log out?</source>
         <translation>Are you sure you want to log out?</translation>
     </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation>Update and Shut Down</translation>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation>Update and Reboot</translation>
+    </message>
+    <message>
+        <source>Closing the programs and shutting down, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Closing the programs and rebooting, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Closing the programs and logging out, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>dss::module::AssistLoginWidget</name>
+    <message>
+        <source>Automatic login</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>dss::module::NetworkModule</name>
