@@ -3,7 +3,7 @@
     <name>AuthFace</name>
     <message>
         <source>Face ID</source>
-        <translation type="unfinished"/>
+        <translation>Face ID</translation>
     </message>
     <message>
         <source>Verification successful</source>
@@ -11,15 +11,15 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
     </message>
     <message>
         <source>Verify your Face ID</source>
-        <translation type="unfinished"/>
+        <translation>Overte svoje Face ID</translation>
     </message>
     <message>
         <source>Face ID locked, use password please</source>
@@ -27,14 +27,14 @@
     </message>
     <message>
         <source>Device unavailable!</source>
-        <translation type="unfinished"/>
+        <translation>Zariadenie nie je dostupné!</translation>
     </message>
 </context>
 <context>
     <name>AuthFingerprint</name>
     <message>
         <source>Verify your fingerprint</source>
-        <translation type="unfinished"/>
+        <translation>Overte svoj odtlačok prsta</translation>
     </message>
     <message>
         <source>Verification successful</source>
@@ -42,11 +42,11 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
     </message>
     <message>
         <source>Fingerprint locked, use password please</source>
@@ -57,7 +57,7 @@
     <name>AuthIris</name>
     <message>
         <source>Iris ID</source>
-        <translation type="unfinished"/>
+        <translation>Iris ID</translation>
     </message>
     <message>
         <source>Verification successful</source>
@@ -65,21 +65,40 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
     </message>
     <message>
         <source>Verify your Iris ID</source>
-        <translation type="unfinished"/>
+        <translation>Overte svoje Iris ID</translation>
     </message>
     <message>
         <source>Iris ID locked, use password please</source>
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>AuthPasskey</name>
+    <message>
+        <source>Please plug in the security key</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Verification successful</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Verification failed</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Identifying the security key</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>AuthPassword</name>
     <message>
@@ -88,11 +107,11 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávaju %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
     </message>
     <message>
         <source>Wrong Password</source>
@@ -112,11 +131,11 @@
     </message>
     <message>
         <source>Reset Password</source>
-        <translation type="unfinished"/>
+        <translation>Obnoviť heslo</translation>
     </message>
     <message>
         <source>Forgot password?</source>
-        <translation type="unfinished"/>
+        <translation>Zabudli ste heslo?</translation>
     </message>
 </context>
 <context>
@@ -131,11 +150,11 @@
     </message>
     <message>
         <source>Reset Password</source>
-        <translation type="unfinished"/>
+        <translation>Obnoviť heslo</translation>
     </message>
     <message>
         <source>Forgot password?</source>
-        <translation type="unfinished"/>
+        <translation>Zabudli ste heslo?</translation>
     </message>
 </context>
 <context>
@@ -146,15 +165,15 @@
     </message>
     <message numerus="yes">
         <source>Verification failed, %n chances left</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Overenie zlyhalo, ostáva %d pokus</numerusform><numerusform>Overenie zlyhalo, ostávajú %d pokusy</numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform><numerusform>Overenie zlyhalo, ostáva %d pokusov </numerusform></translation>
     </message>
     <message>
         <source>Verification failed, only one chance left</source>
-        <translation type="unfinished"/>
+        <translation>Overenie zlyhalo, ostáva iba jeden pokus</translation>
     </message>
     <message>
         <source>Wrong PIN</source>
-        <translation type="unfinished"/>
+        <translation>Nesprávny PIN</translation>
     </message>
     <message>
         <source>UKey is required</source>
@@ -162,7 +181,7 @@
     </message>
     <message>
         <source>Enter your PIN</source>
-        <translation type="unfinished"/>
+        <translation>Zadajte svoj PIN</translation>
     </message>
     <message numerus="yes">
         <source>Please try again %n minute(s) later</source>
@@ -185,88 +204,33 @@
     </message>
     <message numerus="yes">
         <source>Your password will expire in %n days, please change it timely</source>
-        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
+        <translation><numerusform>Vaše heslo vyprší za %d deň, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dni, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dní, zmeňte si ho prosím včas</numerusform><numerusform>Vaše heslo vyprší za %d dní, zmeňte si ho prosím včas</numerusform></translation>
     </message>
     <message>
-        <source>Your password has expired. Please contact the administrator to change it.</source>
+        <source>Password expired, please change</source>
+        <translation>Platnosť hesla vypršala, zmeňte ho prosím</translation>
+    </message>
+    <message>
+        <source>Your password has expired. Please contact the administrator to change it</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>Your password has expired. Please change it.</source>
+        <source>Terminal locked, please contact administrator</source>
         <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>ChangePasswordWidget</name>
+    <name>DeepinAuthFramework</name>
     <message>
-        <source>Your password has expired. Please change it and log in again.</source>
+        <source>Wrong Password</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Save</source>
-        <translation>Uložiť</translation>
-    </message>
-    <message>
-        <source>Old password</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New password</source>
-        <translation>Nové heslo</translation>
-    </message>
-    <message>
-        <source>Repeat new password</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password hint (Optional)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Passwords do not match</source>
-        <translation>Heslá sa nezhodujú</translation>
-    </message>
-    <message>
-        <source>The hint is visible to all users. Do not include the password here.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>New password should differ from the current one</source>
-        <translation>Nové heslo by sa malo líšiť od aktuálneho</translation>
-    </message>
-    <message>
-        <source>Password changed</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Wrong password</source>
-        <translation>Chybné heslo</translation>
-    </message>
-</context>
-<context>
-    <name>ControlWidget</name>
-    <message>
-        <source>Desktop Environment and Display Protocol</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Keyboard Layout</source>
-        <translation>Rozloženie klávesnice</translation>
-    </message>
-    <message>
-        <source>Switch User</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Power</source>
-        <translation>Napájanie</translation>
-    </message>
 </context>
 <context>
     <name>GreeterWorker</name>
     <message>
         <source>Wrong account</source>
-        <translation type="unfinished"/>
+        <translation>Nesprávny účet</translation>
     </message>
     <message>
         <source>Wrong Password</source>
@@ -279,6 +243,17 @@
         <source>Cancel</source>
         <translation>Zrušiť</translation>
     </message>
+    <message>
+        <source>The reason of inhibit.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>LighterGreeter</name>
+    <message>
+        <source>Standard Mode</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>LockContent</name>
@@ -318,68 +293,9 @@
     </message>
 </context>
 <context>
-    <name>PasswordLevelWidget</name>
+    <name>SessionWidget</name>
     <message>
-        <source>Weak</source>
-        <translation>Slabé</translation>
-    </message>
-    <message>
-        <source>Medium</source>
-        <translation>Stredne</translation>
-    </message>
-    <message>
-        <source>Strong</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
-<context>
-    <name>PwqualityManager</name>
-    <message>
-        <source>Password cannot be empty</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password must have at least %1 characters</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password must be no more than %1 characters</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>No more than %1 palindrome characters please</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>No more than %1 monotonic characters please</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>No more than %1 repeating characters please</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Password must not contain more than 4 palindrome characters</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Do not use common words and combinations as password</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Create a strong password please</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>It does not meet password rules</source>
+        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -409,13 +325,21 @@
         <source>Log out</source>
         <translation>Odhlásiť</translation>
     </message>
+    <message>
+        <source>Switch user</source>
+        <translation>Prepnúť užívateľa</translation>
+    </message>
     <message>
         <source>Switch system</source>
         <translation>Prepnúť systém</translation>
     </message>
     <message>
-        <source>Switch user</source>
-        <translation>Prepnúť užívateľa</translation>
+        <source>Update and Shut Down</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -426,25 +350,52 @@
     </message>
 </context>
 <context>
-    <name>UserListPopupWidget</name>
+    <name>UdcpMFALoginWidget</name>
     <message>
-        <source>Standard User</source>
-        <translation>Štandardný používateľ</translation>
+        <source>发送验证码</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Administrator</source>
-        <translation>Administrátor</translation>
+        <source>请输入手机号</source>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Other Users</source>
+        <source>请输入验证码</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>获取验证码</source>
         <translation type="unfinished"/>
     </message>
 </context>
 <context>
-    <name>VirtualKeyboardModule</name>
+    <name>UpdateWorker</name>
     <message>
-        <source>Onboard</source>
-        <translation>Onboard</translation>
+        <source>Update</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please plug in and then install updates.</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>UsersWithTheSameName</name>
+    <message>
+        <source>Return</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Please select the account for login</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Local Account</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Domain Account</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -505,16 +456,43 @@
         <source>Are you sure you want to log out?</source>
         <translation>Určite sa chcete odhlásiť?</translation>
     </message>
+    <message>
+        <source>Update and Shut Down</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Update and Reboot</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Closing the programs and shutting down, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Closing the programs and rebooting, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Closing the programs and logging out, please wait...</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+<context>
+    <name>dss::module::AssistLoginWidget</name>
+    <message>
+        <source>Automatic login</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>dss::module::NetworkModule</name>
     <message>
         <source>Turn on</source>
-        <translation type="unfinished"/>
+        <translation>Zapnúť</translation>
     </message>
     <message>
         <source>Turn off</source>
-        <translation type="unfinished"/>
+        <translation>Vypnúť</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
